from unittest import mock

from django.contrib.auth.models import User  # noqa


Choice = mock.MagicMock()
Poll = mock.MagicMock()
MyModel = mock.MagicMock()
